summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/qtopia4app
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/qtopia4app')
-rw-r--r--languages/cpp/app_templates/qtopia4app/example.cpp12
-rw-r--r--languages/cpp/app_templates/qtopia4app/example.h5
-rw-r--r--languages/cpp/app_templates/qtopia4app/example.html4
-rw-r--r--languages/cpp/app_templates/qtopia4app/examplebase.ui10
-rw-r--r--languages/cpp/app_templates/qtopia4app/main.cpp6
5 files changed, 19 insertions, 18 deletions
diff --git a/languages/cpp/app_templates/qtopia4app/example.h b/languages/cpp/app_templates/qtopia4app/example.h
index 5bfc69ba..e4c44a8f 100644
--- a/languages/cpp/app_templates/qtopia4app/example.h
+++ b/languages/cpp/app_templates/qtopia4app/example.h
@@ -6,15 +6,16 @@
class %{APPNAME}Base : public TQWidget, public Ui_%{APPNAME}Base
{
public:
- %{APPNAME}Base( TQWidget *parent = 0, Qt::WFlags f = 0 );
+ %{APPNAME}Base( TQWidget *tqparent = 0, TQt::WFlags f = 0 );
virtual ~%{APPNAME}Base();
};
class %{APPNAME} : public %{APPNAME}Base
{
Q_OBJECT
+ TQ_OBJECT
public:
- %{APPNAME}( TQWidget *parent = 0, Qt::WFlags f = 0 );
+ %{APPNAME}( TQWidget *tqparent = 0, TQt::WFlags f = 0 );
virtual ~%{APPNAME}();
private slots:
diff --git a/languages/cpp/app_templates/qtopia4app/example.html b/languages/cpp/app_templates/qtopia4app/example.html
index 279a6106..9bcae99d 100644
--- a/languages/cpp/app_templates/qtopia4app/example.html
+++ b/languages/cpp/app_templates/qtopia4app/example.html
@@ -6,10 +6,10 @@
<p>To user this application:
<ol>
- <li>Press the <img width=12 height=12 src=%{APPNAME}.png> icon in the Qtopia launcher.
+ <li>Press the <img width=12 height=12 src=%{APPNAME}.png> icon in the TQtopia launcher.
<li>Read the label.
<li>Press the button.
<li>Read the source code provided.
</ol>
-Now you know how to make a Qtopia application!
+Now you know how to make a TQtopia application!
diff --git a/languages/cpp/app_templates/qtopia4app/examplebase.ui b/languages/cpp/app_templates/qtopia4app/examplebase.ui
index 17d6bc20..76e7d49f 100644
--- a/languages/cpp/app_templates/qtopia4app/examplebase.ui
+++ b/languages/cpp/app_templates/qtopia4app/examplebase.ui
@@ -3,7 +3,7 @@
<comment></comment>
<exportmacro></exportmacro>
<class>%{APPNAME}Base</class>
- <widget class="QWidget" name="%{APPNAME}Base" >
+ <widget class="TQWidget" name="%{APPNAME}Base" >
<property name="geometry" >
<rect>
<x>0</x>
@@ -15,7 +15,7 @@
<property name="windowTitle" >
<string>%{APPNAME}</string>
</property>
- <layout class="QVBoxLayout" >
+ <tqlayout class="TQVBoxLayout" >
<property name="margin" >
<number>11</number>
</property>
@@ -23,7 +23,7 @@
<number>6</number>
</property>
<item>
- <widget class="QLabel" name="TextLabel1" >
+ <widget class="TQLabel" name="TextLabel1" >
<property name="text" >
<string>This is just an %{APPNAME}. It doesn't do anything interesting at all.</string>
</property>
@@ -33,12 +33,12 @@
</widget>
</item>
<item>
- <widget class="QPushButton" name="quit" >
+ <widget class="TQPushButton" name="quit" >
<property name="text" >
<string>Quit</string>
</property>
</widget>
</item>
- </layout>
+ </tqlayout>
</widget>
</ui>
diff --git a/languages/cpp/app_templates/qtopia4app/main.cpp b/languages/cpp/app_templates/qtopia4app/main.cpp
index 43dbb4ac..b4ccc5ca 100644
--- a/languages/cpp/app_templates/qtopia4app/main.cpp
+++ b/languages/cpp/app_templates/qtopia4app/main.cpp
@@ -1,7 +1,7 @@
#include "%{APPNAMELC}.h"
-#include <qtopia/qtopiaapplication.h>
+#include <tqtopia/tqtopiaapplication.h>
-QTOPIA_ADD_APPLICATION("%{APPNAMELC}", %{APPNAME})
-QTOPIA_MAIN
+TQTOPIA_ADD_APPLICATION("%{APPNAMELC}", %{APPNAME})
+TQTOPIA_MAIN
diff --git a/languages/cpp/app_templates/qtopia4app/example.cpp b/languages/cpp/app_templates/qtopia4app/example.cpp
index 45331649..12c3f634 100644
--- a/languages/cpp/app_templates/qtopia4app/example.cpp
+++ b/languages/cpp/app_templates/qtopia4app/example.cpp
@@ -2,8 +2,8 @@
#include "%{APPNAMELC}.h"
#include <tqpushbutton.h>
-%{APPNAME}Base::%{APPNAME}Base( TQWidget *parent, Qt::WFlags f )
- : TQWidget( parent, f )
+%{APPNAME}Base::%{APPNAME}Base( TQWidget *tqparent, TQt::WFlags f )
+ : TQWidget( tqparent, f )
{
setupUi( this );
}
@@ -13,11 +13,11 @@
}
/*
* Constructs a %{APPNAME} which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/
-%{APPNAME}::%{APPNAME}( TQWidget *parent, Qt::WFlags f )
- : %{APPNAME}Base( parent, f )
+%{APPNAME}::%{APPNAME}( TQWidget *tqparent, TQt::WFlags f )
+ : %{APPNAME}Base( tqparent, f )
{
connect(quit, TQT_SIGNAL(clicked()), this, TQT_SLOT(goodBye()));
}
@@ -27,7 +27,7 @@
*/
%{APPNAME}::~%{APPNAME}()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -13,11 +13,11 @@
}
/*
- * Constructs a %{APPNAME} which is a child of 'parent', with the
+ * Constructs a %{APPNAME} which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/